@@ -4,11 +4,12 @@ import subprocess
 import tempfile
 import os
 from mOTUlizer.config import *
-from random import shuffle, choice
+from random import shuffle, choice, choices
 from math import log10
 import sys
 import json
 
+
 mean = lambda x : sum(x)/len(x)
 
 class mOTU:
@@ -45,8 +46,8 @@ class mOTU:
                 checkm_dict[f] = 100*len(self.cog_dict[f])/max_len
 
         self.members = [MetaBin(bin_name, cogs = self.cog_dict[bin_name], faas = self.faas.get(bin_name), fnas = None, complet = checkm_dict.get(bin_name)) for bin_name in self.cog_dict.keys()]
-
-        self.cogCounts = {c : 0 for c in set.union(*[mag.cogs for mag in self.members])}
+        self.mock = None
+        self.cogCounts = {c : 0 for c in set.union(set([cog for mag in self.members for cog in mag.cogs]))}
         for mag in self.members:
             for cog in mag.cogs:
                     self.cogCounts[cog] += 1
@@ -58,6 +59,23 @@ class mOTU:
     def __getitem__(self, i):
         return self.members[i]
 
+
+    def roc_values(self):
+        from mOTUlizer.classes.MockData import MockmOTU
+
+        if self.mock is None:
+            completnesses = {"Genome_{}".format(i) : c.new_completness for i,c in enumerate(self)}
+
+            accessory = sorted([v for k,v in self.cogCounts.items() if k not in self.core])
+            missing = int(sum(accessory)*(1-mean(list(completnesses.values()))/100))
+            addeds = choices(list(range(len(accessory))), weights = accessory, k = missing)
+            for k in addeds :
+                accessory[k] += 1
+
+            self.mock = MockmOTU(self.name + "_mock", len(self.core), len(self), lambda g : completnesses[g], accessory = accessory)
+        return { 'recall' : self.mock.recall, 'lowest_false' : self.mock.lowest_false, 'fpr' : self.mock.fpr }
+
+
     def avg_cog_content(self):
         return sum([len(m.cogs) for m in self.members])/len(self)
 
@@ -184,9 +202,9 @@ class mOTU:
 #        mag_prob = {mag : ( 1-1/pool_size )**len(mag.cogs) for mag in self}
 #        mag_prob = {mag : ( 1-1/pool_size )**(len(mag.cogs)-(core_size*comp(mag))) for mag in self}
 #        mag_prob = {mag : ( 1-self.cogCounts[cog]/pool_size )**(len(mag.cogs)-(core_size*comp(mag))) for mag in self}
-        mag_prob = {mag : ( 1-self.cogCounts[cog]/pool_size )**(len(mag.cogs)-(core_size*comp(mag))) for mag in self}
 
-#        mag_prob = {mag : ( 1-self.cogCounts[cog]/pool_size)**len(mag.cogs) for mag in self}
+#        mag_prob = {mag : ( 1-self.cogCounts[cog]/pool_size )**(len(mag.cogs)-(core_size*comp(mag))) for mag in self}
+        mag_prob = {mag : ( 1-self.cogCounts[cog]/pool_size)**len(mag.cogs) for mag in self}
 
         presence = [ log10(1 -   mag_prob[mag]) if mag_prob[mag] < 1 else MIN_PROB                for mag in self if cog in mag.cogs]
         abscence = [ log10(      mag_prob[mag]) if mag_prob[mag] > 0 else log10(1-(10**MIN_PROB)) for mag in self if cog not in mag.cogs]
